@@ -1,8 +1,8 @@
 """DeepVisionGuru utilities"""
 
 # Version of the dvgutils package
-__version__ = "0.1.1"
+__version__ = "0.1.2"
 
 from .logger import setup_logger
-from .config import load_config
+from .config import load_config, overwrite_config
 from .colors import colors
